==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Binary/StdMem.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95stdmem	((void*)startLabel+8)
#define CT_v176	((void*)startLabel+32)
#define CF_NHC_46Binary_46hs_95stdmem	((void*)startLabel+40)
#define CT_v179	((void*)startLabel+88)
#define PP_NHC_46Binary_46hs_95stdmem	((void*)startLabel+120)
#define PC_NHC_46Binary_46hs_95stdmem	((void*)startLabel+120)
#define ST_v175	((void*)startLabel+120)
#define ST_v178	((void*)startLabel+144)
#define PS_v174	((void*)startLabel+164)
#define PS_v177	((void*)startLabel+176)
void FR_NHC_46Binary_46hs_95stdmem(void);
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];

static Node startLabel[] = {
  bytes2word(0,0,0,0)
, useLabel(CT_v176)
,	/* FN_NHC_46Binary_46hs_95stdmem: (byte 0) */
  bytes2word(PRIMITIVE,NOP,NOP,NOP)
, useLabel(FR_NHC_46Binary_46hs_95stdmem)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v175)
,	/* CT_v176: (byte 0) */
  HW(0,0)
, 0
,	/* CF_NHC_46Binary_46hs_95stdmem: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95stdmem))
, useLabel(PS_v174)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v179)
,};
Node FN_NHC_46Binary_46stdmem[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v178)
,	/* CT_v179: (byte 0) */
  HW(1,0)
, 0
,};
Node CF_NHC_46Binary_46stdmem[] = {
  VAPTAG(useLabel(FN_NHC_46Binary_46stdmem))
, useLabel(PS_v177)
, 0
, 0
, 0
, useLabel(CF_NHC_46Binary_46hs_95stdmem)
,	/* PP_NHC_46Binary_46hs_95stdmem: (byte 0) */
 	/* PC_NHC_46Binary_46hs_95stdmem: (byte 0) */
 	/* ST_v175: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,115,116)
, bytes2word(100,109,101,109)
, bytes2word(0,0,0,0)
,};
Node PP_NHC_46Binary_46stdmem[] = {
 };
Node PC_NHC_46Binary_46stdmem[] = {
 	/* ST_v178: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,115)
, bytes2word(116,100,109,101)
, bytes2word(109,0,0,0)
,	/* PS_v174: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95stdmem)
, useLabel(PC_NHC_46Binary_46hs_95stdmem)
,	/* PS_v177: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46stdmem)
, useLabel(PC_NHC_46Binary_46stdmem)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_stdmem" NHC.Binary.hs_stdmem 0 ::  -> FFI.ForeignObj */
extern void* hs_stdmem();
#ifdef PROFILE
static SInfo pf_hs_stdmem = {"NHC.Binary","NHC.Binary.hs_stdmem","FFI.ForeignObj"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95stdmem) {
  NodePtr nodeptr;
  void* result;
;

  result = hs_stdmem();

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_hs_stdmem);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Binary/StdMem.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95stdmem	((void*)startLabel+8)
#define CT_v180	((void*)startLabel+32)
#define CF_NHC_46Binary_46hs_95stdmem	((void*)startLabel+40)
#define CT_v183	((void*)startLabel+88)
#define PP_NHC_46Binary_46hs_95stdmem	((void*)startLabel+120)
#define PC_NHC_46Binary_46hs_95stdmem	((void*)startLabel+120)
#define ST_v179	((void*)startLabel+120)
#define ST_v182	((void*)startLabel+144)
#define PS_v178	((void*)startLabel+164)
#define PS_v181	((void*)startLabel+176)
void FR_NHC_46Binary_46hs_95stdmem(void);
extern Node PM_NHC_46Binary[];

static Node startLabel[] = {
  bytes2word(0,0,0,0)
, useLabel(CT_v180)
,	/* FN_NHC_46Binary_46hs_95stdmem: (byte 0) */
  bytes2word(PRIMITIVE,NOP,NOP,NOP)
, useLabel(FR_NHC_46Binary_46hs_95stdmem)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v179)
,	/* CT_v180: (byte 0) */
  HW(0,0)
, 0
,	/* CF_NHC_46Binary_46hs_95stdmem: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95stdmem))
, useLabel(PS_v178)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v183)
,};
Node FN_NHC_46Binary_46stdmem[] = {
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(PUSH_P1,0,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v182)
,	/* CT_v183: (byte 0) */
  HW(1,0)
, 0
,};
Node CF_NHC_46Binary_46stdmem[] = {
  VAPTAG(useLabel(FN_NHC_46Binary_46stdmem))
, useLabel(PS_v181)
, 0
, 0
, 0
, useLabel(CF_NHC_46Binary_46hs_95stdmem)
,	/* PP_NHC_46Binary_46hs_95stdmem: (byte 0) */
 	/* PC_NHC_46Binary_46hs_95stdmem: (byte 0) */
 	/* ST_v179: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,115,116)
, bytes2word(100,109,101,109)
, bytes2word(0,0,0,0)
,};
Node PP_NHC_46Binary_46stdmem[] = {
 };
Node PC_NHC_46Binary_46stdmem[] = {
 	/* ST_v182: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,115)
, bytes2word(116,100,109,101)
, bytes2word(109,0,0,0)
,	/* PS_v178: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95stdmem)
, useLabel(PC_NHC_46Binary_46hs_95stdmem)
,	/* PS_v181: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46stdmem)
, useLabel(PC_NHC_46Binary_46stdmem)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_stdmem" NHC.Binary.hs_stdmem 0 ::  -> FFI.ForeignObj */
extern void* hs_stdmem();
#ifdef PROFILE
static SInfo pf_NHC_46Binary_46hs_95stdmem = {"NHC.Binary","NHC.Binary.hs_stdmem","FFI.ForeignObj"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95stdmem) {
  NodePtr nodeptr;
  void* result;
;

  result = hs_stdmem();

  nodeptr = result;
  INIT_PROFINFO(nodeptr,&pf_NHC_46Binary_46hs_95stdmem);
  C_RETURN(nodeptr);
}
